.. _api_interfaces_section:

Zope Interfaces
---------------

:class:`Products.mcdutils.interfaces.ISessionDataContainer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.ISessionDataContainer
   :members:

:class:`Products.mcdutils.interfaces.IMemCacheMapping`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.IMemCacheMapping
   :members:
   :inherited-members:

:class:`Products.mcdutils.interfaces.IMemCacheProxy`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.IMemCacheProxy
   :members:
   :inherited-members:

:class:`Products.mcdutils.interfaces.IMemCacheSessionDataContainer`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.IMemCacheSessionDataContainer
   :members:
   :inherited-members:

:class:`Products.mcdutils.interfaces.IZCache`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.IZCache
   :members:
   :inherited-members:

:class:`Products.mcdutils.interfaces.IZCacheManager`
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
.. autointerface:: Products.mcdutils.interfaces.IZCacheManager
   :members:
   :inherited-members:
